"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mock_authorization_functions = void 0;
function mock_authorization_functions(config) {
    function match(tuple) {
        for (const item of config) {
            if (item.subject && item.subject !== tuple.subject)
                continue;
            if (item.action && item.action !== tuple.action)
                continue;
            if (item.object && item.object !== tuple.object)
                continue;
            return { result: item.result, reason: item.reason };
        }
        return { result: false, reason: 'No match' };
    }
    async function check_authorization(subject_or_tuple, action, object) {
        let tuples;
        if (Array.isArray(subject_or_tuple)) {
            tuples = subject_or_tuple;
            if (tuples.length === 0) {
                return [];
            }
        }
        else {
            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
            tuples = [{ subject: subject_or_tuple, action: action, object: object }];
        }
        const result = tuples.map(match);
        if (Array.isArray(subject_or_tuple)) {
            return result.map((r) => ({
                result: r.result ?? false,
                reason: r.reason,
            }));
        }
        else {
            return { result: result[0].result ?? false, reason: result[0].reason };
        }
    }
    async function update_relations(_add, _remove) {
        throw Error('Not implemented');
    }
    async function relate(_subject_or_tuples, _relation, _object) {
        throw Error('Not implemented');
    }
    async function unrelate(_subject_or_tuples, _relation, _object) {
        throw Error('Not implemented');
    }
    async function query(_subject, _relation, _object) {
        throw Error('Not implemented');
    }
    return { check_authorization, update_relations, relate, unrelate, query };
}
exports.mock_authorization_functions = mock_authorization_functions;
//# sourceMappingURL=mock.js.map