"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AbstractRepositoryTestSuite = void 0;
const mocha_1 = __importDefault(require("mocha"));
const create_spec_js_1 = require("./create.spec.js");
const find_spec_js_1 = require("./find.spec.js");
const findOne_spec_js_1 = require("./findOne.spec.js");
const findOneOrFail_spec_js_1 = require("./findOneOrFail.spec.js");
const format_spec_js_1 = require("./format.spec.js");
const remove_spec_js_1 = require("./remove.spec.js");
const save_spec_js_1 = require("./save.spec.js");
const write_spec_js_1 = require("./write.spec.js");
/**
 * An abstract class for a repository.
 * @typeParam K - Keys of the EntityData
 * @typeParam R - Type of the Repository
 */
class AbstractRepositoryTestSuite {
    constructor(AppDataSource) {
        this.AppDataSource = AppDataSource;
    }
    async initialize() {
        this.entityData = await this.getEntityData();
        this.repositoryTestData = {
            entityData: this.entityData,
            repository: this.repository,
            compareModels: this.compareModels.bind(this),
            compareFormatted: this.compareFormatted.bind(this),
            getFindOptionsWhere: this.getFindOptionsWhere.bind(this),
            validateCreate: this.validateCreate.bind(this),
            validateFormat: this.validateFormat.bind(this),
            validateWrite: this.validateWrite.bind(this),
            RepositoryClass: this.RepositoryClass,
        };
        this.testSuites = {
            additional: (() => {
                const testSuite = new mocha_1.default.Suite('additional');
                return testSuite;
            })(),
            create: (0, create_spec_js_1.testSuiteCreate)(this.repositoryTestData),
            find: (0, find_spec_js_1.testSuiteFind)(this.repositoryTestData),
            findOne: (0, findOne_spec_js_1.testSuiteFindOne)(this.repositoryTestData),
            findOneOrFail: (0, findOneOrFail_spec_js_1.testSuiteFindOneOrFail)(this.repositoryTestData),
            format: (0, format_spec_js_1.testSuiteFormat)(this.repositoryTestData),
            remove: (0, remove_spec_js_1.testSuiteRemove)(this.repositoryTestData),
            save: (0, save_spec_js_1.testSuiteSave)(this.repositoryTestData),
            write: (0, write_spec_js_1.testSuiteWrite)(this.repositoryTestData),
        };
    }
    addTestToSuite(suiteName, test) {
        if (!this.testSuites || !this.repositoryTestData)
            throw new Error('Test suite has not been initialized');
        this.testSuites[suiteName].addTest(test(this.repositoryTestData));
    }
    addSuiteToSuite(suiteName, suite) {
        if (!this.testSuites || !this.repositoryTestData)
            throw new Error('Test suite has not been initialized');
        this.testSuites[suiteName].addSuite(suite(this.repositoryTestData));
    }
    addSuite(suiteName, suite) {
        if (!this.testSuites || !this.repositoryTestData)
            throw new Error('Test suite has not been initialized');
        this.testSuites[suiteName] = suite(this.repositoryTestData);
    }
    removeSuite(suiteName) {
        if (!this.testSuites || !this.repositoryTestData)
            throw new Error('Test suite has not been initialized');
        delete this.testSuites[suiteName];
    }
    async resetDatabase() {
        if (this.AppDataSource.connected) {
            await this.AppDataSource.teardown();
        }
        const newEntityData = await this.getEntityData();
        for (const key in newEntityData) {
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            this.entityData[key] = newEntityData[key];
        }
    }
    execute() {
        const testSuites = this.testSuites;
        const testSuite = new mocha_1.default.Suite(`${this.repository.name} Repository Test`);
        for (const suite in testSuites) {
            const boundResetDatabase = this.resetDatabase.bind(this);
            testSuites[suite].beforeEach(async function () {
                await boundResetDatabase();
            });
            testSuite.addSuite(testSuites[suite]);
        }
        return testSuite;
    }
}
exports.AbstractRepositoryTestSuite = AbstractRepositoryTestSuite;
//# sourceMappingURL=abstractRepository.spec.js.map