"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ValidationError = exports.DeviceOwnershipError = exports.UninitializedRepositoryError = exports.MalformedParameterError = exports.MissingParameterError = exports.MalformedBodyError = exports.JWTVerificationError = exports.DeviceNotConnectedError = exports.InvalidChangeError = exports.InconsistentDatabaseError = exports.InvalidValueError = exports.ImpossibleOperationError = exports.ForbiddenOperationError = exports.UnrelatedPeerconnectionError = exports.MissingPropertyError = exports.MissingEntityError = exports.UnauthorizedError = exports.ForbiddenError = exports.InternalServerError = exports.HttpError = exports.ErrorWithStatus = void 0;
class ErrorWithStatus extends Error {
    constructor(message, status, innerError) {
        super(message);
        this.status = status;
        this.name = 'ErrorWithStatus';
        this.innerError = innerError;
    }
}
exports.ErrorWithStatus = ErrorWithStatus;
class HttpError extends ErrorWithStatus {
    constructor(status, message, innerError) {
        super(message, status, innerError);
        this.name = 'HttpError';
    }
}
exports.HttpError = HttpError;
class InternalServerError extends ErrorWithStatus {
    constructor(message, innerError) {
        super(message, 500, innerError);
        this.name = 'InternalServerError';
    }
}
exports.InternalServerError = InternalServerError;
class ForbiddenError extends ErrorWithStatus {
    constructor(message = 'Forbidden') {
        super(message, 403);
        this.name = 'ForbiddenError';
    }
}
exports.ForbiddenError = ForbiddenError;
class UnauthorizedError extends ErrorWithStatus {
    constructor(message = 'Unauthorized') {
        super(message, 401);
        this.name = 'UnauthorizedError';
    }
}
exports.UnauthorizedError = UnauthorizedError;
/**
 * This error class should be used if an entity is not found in the database.
 */
class MissingEntityError extends ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'MissingEntityError';
    }
}
exports.MissingEntityError = MissingEntityError;
/**
 * This error class should be used if an object is missing a needed property.
 */
class MissingPropertyError extends ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'MissingPropertyError';
    }
}
exports.MissingPropertyError = MissingPropertyError;
/**
 * This error class should be used if a device is not related to a peerconnection.
 */
class UnrelatedPeerconnectionError extends ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'UnrelatedPeerconnectionError';
    }
}
exports.UnrelatedPeerconnectionError = UnrelatedPeerconnectionError;
/**
 * This error class should be used if an operation is forbidden for the user.
 */
class ForbiddenOperationError extends ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'ForbiddenOperationError';
    }
}
exports.ForbiddenOperationError = ForbiddenOperationError;
/**
 * This error class should be used if an operation is impossible.
 */
class ImpossibleOperationError extends ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'ImpossibleOperationError';
    }
}
exports.ImpossibleOperationError = ImpossibleOperationError;
/**
 * This error class should be used if an object contains an invalid value.
 */
class InvalidValueError extends ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'InvalidValueError';
    }
}
exports.InvalidValueError = InvalidValueError;
/**
 * This error class should be used if there is an inconsistency in the database.
 */
class InconsistentDatabaseError extends ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'InconsistentDatabaseError';
    }
}
exports.InconsistentDatabaseError = InconsistentDatabaseError;
/**
 * This error class should be used if the user attempts an invalid change.
 */
class InvalidChangeError extends ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'InvalidChangeError';
    }
}
exports.InvalidChangeError = InvalidChangeError;
/**
 * This error class should be used if a required device is not connection.
 */
class DeviceNotConnectedError extends ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'DeviceNotConnectedError';
    }
}
exports.DeviceNotConnectedError = DeviceNotConnectedError;
/**
 * This error class should be used if an error occurs during JWT verification.
 */
class JWTVerificationError extends ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'JWTVerificationError';
    }
}
exports.JWTVerificationError = JWTVerificationError;
/**
 * This error class should be used if the body of a request is malformed.
 */
class MalformedBodyError extends ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'MalformedBodyError';
    }
}
exports.MalformedBodyError = MalformedBodyError;
/**
 * This error class should be used if a parameter of a request is missing.
 */
class MissingParameterError extends ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'MissingParameterError';
    }
}
exports.MissingParameterError = MissingParameterError;
/**
 * This error class should be used if a parameter of a request is malformed.
 */
class MalformedParameterError extends ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'MalformedParameterError';
    }
}
exports.MalformedParameterError = MalformedParameterError;
/**
 * This error class should be used when a repository has not been initialized before use.
 */
class UninitializedRepositoryError extends ErrorWithStatus {
    constructor(message) {
        super(message, 500);
        this.name = 'UninitializedRepositoryError';
    }
}
exports.UninitializedRepositoryError = UninitializedRepositoryError;
/**
 * This error class should be used when an user is not the owner of a device.
 */
class DeviceOwnershipError extends ErrorWithStatus {
    constructor() {
        super(`User is not the owner of the device and does not have further permission`, 403);
        this.name = 'OwnershipError';
    }
}
exports.DeviceOwnershipError = DeviceOwnershipError;
class ValidationError extends ErrorWithStatus {
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    constructor(message, status, errors) {
        super(message, status);
        this.name = 'ValidationError';
        this.errors = errors;
    }
}
exports.ValidationError = ValidationError;
//# sourceMappingURL=errors.js.map