"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseConfig = void 0;
const utils_js_1 = require("../utils.js");
const config_js_1 = require("./config.js");
function parseConfig(config) {
    let LOGGING = config.LOGGING ?? 'info';
    let LOGGING_TRANSPORT = config.LOGGING_TRANSPORT ?? 'stdout';
    LOGGING =
        LOGGING in config_js_1.logLevelMapping
            ? LOGGING
            : (0, utils_js_1.die)('DEBUG must be on of ' + Object.keys(config_js_1.logLevelMapping).join(','));
    // Parse Debug Transport as '{transport}#{parameter},{transport}#{parameter},...'
    if (typeof LOGGING_TRANSPORT === 'string') {
        LOGGING_TRANSPORT = LOGGING_TRANSPORT.split(',').map(transport => {
            const [transportName, ...parameters] = transport.split('#');
            const transportConfig = {
                transport: transportName,
            };
            if (transportConfig.transport === 'loki') {
                transportConfig.host = parameters[0] ?? (0, utils_js_1.die)('Loki transport requires a host');
            }
            else if (transportConfig.transport === 'file') {
                transportConfig.filename =
                    parameters[0] ?? (0, utils_js_1.die)('File transport requires a filename');
            }
            return transportConfig;
        });
    }
    if (!Array.isArray(LOGGING_TRANSPORT))
        LOGGING_TRANSPORT = [LOGGING_TRANSPORT];
    const LOGGING_LABELS = typeof config.LOGGING_LABELS === 'string' ? JSON.parse(config.LOGGING_LABELS) : config.LOGGING_LABELS;
    return { LOGGING: LOGGING, LOGGING_TRANSPORT, LOGGING_LABELS };
}
exports.parseConfig = parseConfig;
//# sourceMappingURL=helper.js.map