"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.middleware = void 0;
const uuid_1 = require("uuid");
const logging_js_1 = require("./logging.js");
const requestId_js_1 = require("./requestId.js");
/**
 * This middleware injects the request id into the request object and logs the request.
 */
function middleware() {
    return function (req, res, next) {
        req.id = req.get('X-Request-ID') ?? (0, uuid_1.v1)();
        req.startTime = Date.now();
        res.on('finish', () => {
            logging_js_1.logger.info({
                message: `${req.method} ${req.url} ${res.statusCode} ${Date.now() - req.startTime}ms`,
                method: req.method,
                url: req.url,
                status: res.statusCode,
                responseTime: Date.now() - req.startTime,
            });
        });
        requestId_js_1.requestIdContext.run(req.id, () => {
            next();
        });
    };
}
exports.middleware = middleware;
//# sourceMappingURL=middleware.js.map