import assert, { fail } from 'assert';
import Mocha from 'mocha';
import { UninitializedRepositoryError } from '../../errors.js';
export function testSuiteCreate(repositoryTestData) {
    const testSuite = new Mocha.Suite('create');
    testSuite.addTest(new Mocha.Test('should create a model from empty data', async function () {
        const model = (await repositoryTestData.repository.create());
        assert(repositoryTestData.validateCreate(model));
    }));
    for (const key in repositoryTestData.entityData) {
        testSuite.addTest(new Mocha.Test(`should create a model from valid data (${key})`, async function () {
            const model = (await repositoryTestData.repository.create(repositoryTestData.entityData[key].request));
            assert(repositoryTestData.validateCreate(model, repositoryTestData.entityData[key].request));
        }));
    }
    testSuite.addTest(new Mocha.Test('should throw an UninitializedRepositoryError if the repository has not been initialized', async function () {
        for (const key in repositoryTestData.entityData) {
            const unitializedRepository = new repositoryTestData.RepositoryClass();
            try {
                await unitializedRepository.create(repositoryTestData.entityData[key].request);
                fail();
            }
            catch (error) {
                assert(error instanceof UninitializedRepositoryError);
            }
        }
    }));
    return testSuite;
}
//# sourceMappingURL=create.spec.js.map