import assert, { fail } from 'assert';
import Mocha from 'mocha';
import { UninitializedRepositoryError } from '../../errors.js';
export function testSuiteRemove(repositoryTestData) {
    const testSuite = new Mocha.Suite('remove');
    for (const key in repositoryTestData.entityData) {
        testSuite.addTest(new Mocha.Test(`should remove a specific existing model (${key})`, async function () {
            const model = (await repositoryTestData.repository.findOne({
                where: repositoryTestData.getFindOptionsWhere(repositoryTestData.entityData[key].model),
            }));
            assert(model);
            assert(repositoryTestData.compareModels(model, repositoryTestData.entityData[key].model, false));
            await repositoryTestData.repository.remove(model);
            assert((await repositoryTestData.repository.findOne({
                where: repositoryTestData.getFindOptionsWhere(repositoryTestData.entityData[key].model),
            })) === null);
        }));
    }
    testSuite.addTest(new Mocha.Test('should throw an UninitializedRepositoryError if the repository has not been initialized', async function () {
        for (const key in repositoryTestData.entityData) {
            const unitializedRepository = new repositoryTestData.RepositoryClass();
            try {
                await unitializedRepository.remove(repositoryTestData.entityData[key].model);
                fail();
            }
            catch (error) {
                assert(error instanceof UninitializedRepositoryError);
            }
        }
    }));
    return testSuite;
}
//# sourceMappingURL=remove.spec.js.map