/// <reference types="qs" />
import * as express from 'express';
import { AuthorizationActionTuple, AuthorizationConfig, AuthorizationRelationTuple, AuthorizationResponse, authorization_functions } from './authorization.js';
import { AuthorizationMockConfig } from './mock.js';
export type AuthorizationActionTupleWithoutSubject = Omit<AuthorizationActionTuple, 'subject'>;
export type AuthorizationRelationTupleWithoutSubject = Omit<AuthorizationRelationTuple, 'subject'>;
declare function bind_authorization(authorization_funs: ReturnType<typeof authorization_functions>, user: string): {
    check_authorization: {
        (tuples: (AuthorizationActionTuple | AuthorizationActionTupleWithoutSubject)[]): Promise<AuthorizationResponse[]>;
        (subject: string, action: string, object: string): Promise<AuthorizationResponse>;
        (action: string, object: string): Promise<AuthorizationResponse>;
    };
    check_authorization_or_fail: {
        (tuples: (AuthorizationActionTuple | AuthorizationActionTupleWithoutSubject)[]): Promise<void>;
        (subject: string, action: string, object: string): Promise<void>;
        (action: string, object: string): Promise<void>;
    };
    filter: <T>(array: T[], action: string, key: (object: T) => string) => Promise<T[]>;
    update_relations: (add: AuthorizationRelationTuple[], remove: AuthorizationRelationTuple[]) => Promise<void>;
    relate: {
        (tuples: AuthorizationRelationTuple[]): Promise<void>;
        (subject: string, relation: string, object: string): Promise<void>;
    };
    unrelate: {
        (tuples: AuthorizationRelationTuple[]): Promise<void>;
        (subject: string, relation: string, object: string): Promise<void>;
    };
    query: (subject: string | undefined, relation: string | undefined, object: string) => Promise<AuthorizationRelationTuple[]>;
};
export type BoundAuthorizationFunctions = ReturnType<typeof bind_authorization>;
declare global {
    namespace Express {
        interface Request {
            authorization: ReturnType<typeof bind_authorization> & {
                user: string;
            };
        }
        interface Application {
            authorization_mock: undefined | AuthorizationMockConfig;
        }
    }
}
/**
 * This middleware adds the authorization functions to the request object.
 *
 * The user is read from the `X-Request-Authentication` header. If the header is not set, the user is set to `user:anonymus`.
 * @param config
 * @returns
 */
export declare function middleware(config?: AuthorizationConfig): express.RequestHandler<import("express-serve-static-core").ParamsDictionary, any, any, import("qs").ParsedQs, Record<string, any>>;
export {};
//# sourceMappingURL=middleware.d.ts.map